Uniform Blocks
**************

.. currentmodule:: ModernGL

.. autoclass:: UniformBlock
	:members: name, index, size, binding

.. autoclass:: UniformBlockMap

	.. automethod:: __getitem__(key) -> UniformBlock

.. toctree::
	:maxdepth: 4
